<?php

declare(strict_types=1);

namespace Drupal\externalauth_force\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Routing\RouteSubscriberBase;
use Symfony\Component\Routing\RouteCollection;

/**
 * Listens to the dynamic route events.
 */
final class RouteSubscriber extends RouteSubscriberBase {

  /**
   * RouteSubscriber constructor.
   */
  public function __construct(
    private readonly ConfigFactoryInterface $configFactory,
  ) {
  }

  /**
   * {@inheritdoc}
   */
  protected function alterRoutes(RouteCollection $collection): void {
    // Optional integration for the "OpenID Connect" module: prevent users from
    // deleting their own authmap entry, even if they have "administer user"
    // permissions.
    $names = [
      'openid_connect.accounts_controller_index',
    ];
    foreach ($names as $name) {
      $route = $collection->get($name);
      $route?->addRequirements([
        '_permission' => 'skip external authentication',
      ]);
    }

    // Disable the user registration and password recovery pages, if regular
    // login is disabled.
    if ($this->configFactory->get('externalauth_force.settings')->get('disable_login')) {
      $names = [
        'user.pass',
        'user.register',
      ];
      foreach ($names as $name) {
        $route = $collection->get($name);
        $route?->setRequirements([
          '_access' => 'FALSE',
        ]);
      }
    }
  }

}
